TranscriptionEvent class

Event for transcription updates

Constructors

TranscriptionEvent({required String text, required TranscriptionType type, bool isPartial = false, DateTime? timestamp})

Properties

hashCode int
The hash code for this object.
no setterinherited
isPartial bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
timestamp DateTime
final
type TranscriptionType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited