WebSocketConnectionState enum

Gemini Live WebSocket Client

A Flutter package for real-time communication with Gemini Live API via WebSocket connection. Supports audio streaming, text messaging, image sending, and transcription. Enum representing the current state of the WebSocket connection

Inheritance
Available extensions

Values

disconnected → const WebSocketConnectionState

Connection is not established

connecting → const WebSocketConnectionState

Connection is being established

connected → const WebSocketConnectionState

Connection is active and ready for communication

error → const WebSocketConnectionState

Connection encountered an error

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WebSocketConnectionState>
A constant List of the values in this enum, in order of their declaration.